==> haskell-rvar-0.3.0.2-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-7Pm0o9HHhKZ6JXrNY0peZv
key:                  rvar-0.3.0.2-7Pm0o9HHhKZ6JXrNY0peZv
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  b9df414b5373be69b112b9c2edcf06a3
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-7Pm0o9HHhKZ6JXrNY0peZv
depends:
    MonadPrompt-1.0.0.5-2LatcwGGS2Q5uLEuFYBrfY base-4.16.4.0
    bytestring-0.11.4.0 mtl-2.2.2 random-1.2.1.2-81vy8e6NCuX1qZ1DGAELzi
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rvar-0.3.0.2-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-7fbiW3bKbkB9mfGQRLX5jc
key:                  rvar-0.3.0.2-7fbiW3bKbkB9mfGQRLX5jc
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  4a6db45f0fe46e7adb22cc8ef378f660
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-7fbiW3bKbkB9mfGQRLX5jc
depends:
    MonadPrompt-1.0.0.5-69ENdtsyMzNBnEHmyqW05t base-4.17.2.1
    bytestring-0.11.5.3 mtl-2.2.2 random-1.2.1.2-J6mYBSGGDLVAHQqGKIioSR
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
